==> vows-ext-0.0.6.tgz: package/lib/http-helper.js <==
(function() {
  var assert, deepCopy, doRequest, exec, inspect, jsonTryParse, makeAuthVal, makeRequest, makeTopicFun, puts, readFile, replacePathVariables, request, _ref;
  var __hasProp = Object.prototype.hasOwnProperty;
  _ref = require('sys'), puts = _ref.puts, inspect = _ref.inspect;
  request = require('request');
  assert = require('assert');
  exec = require('child_process').exec;
  readFile = require('fs').readFile;
  jsonTryParse = function(json, val) {
    try {
      return JSON.parse(json);
    } catch (e) {
      return val || null;
    }
  };
  deepCopy = function(obj) {
    var el, name, out, val, _i, _len, _results;
    if (obj === null) {
      return null;
    } else if (Array.isArray(obj)) {
      _results = [];
      for (_i = 0, _len = obj.length; _i < _len; _i++) {
        el = obj[_i];
        _results.push(deepCopy(el));
      }
      return _results;
    } else if (typeof obj === 'object') {
      out = {};
      for (name in obj) {
        val = obj[name];
        out[name] = deepCopy(val);
      }
      return out;
    } else {
      return obj;
    }
  };
  exports.buildRequest = function(host, opts) {
    var requestOptions, rv;
    if (opts == null) {
      opts = {};
    }
    requestOptions = deepCopy(opts);
    rv = {
      shouldRespond: function(statusCode, additionalVows) {
        var context, fun, name;
        if (additionalVows == null) {
          additionalVows = {};
        }
        context = {
          topic: makeTopicFun(host, requestOptions)
        };
        for (name in additionalVows) {
          fun = additionalVows[name];
          context[name] = fun;
        }
        context["should respond with a " + statusCode] = function(res) {
          return assert.equal(res.statusCode, statusCode);
        };
        return context;
      },
      "with": function(moreOpts) {
        var name, val, _ref;
        requestOptions = deepCopy(requestOptions);
        _ref = deepCopy(moreOpts);
        for (name in _ref) {
          val = _ref[name];
          requestOptions[name] = val;
        }
        return rv;
      }
    };
    return rv;
  };
  makeTopicFun = function(host, opts) {
    return function(obj) {
      var method, path, reqFun, url, _ref;
      _ref = this.context.name.split(/\s+/), method = _ref[0], path = _ref[1];
      if (obj != null) {
        path = replacePathVariables(path, obj);
      }
      url = "http://" + host + path;
      return reqFun = makeRequest(method, url, opts, this.callback);
    };
  };
  makeAuthVal = function(creds) {
    var encoded;
    encoded = new Buffer("" + creds.username + ":" + creds.password).toString('base64');
    return "Basic " + encoded;
  };
  replacePathVariables = function(path, obj) {
    return path.replace(/:([a-z_]+)/gi, function(_, name) {
      var val;
      val = obj[name];
      if (typeof val === 'function') {
        return val.apply(obj);
      } else if (val != null) {
        return val;
      } else {
        return '';
      }
    });
  };
  makeRequest = function(method, url, opts, cb) {
    var body, bodyFromFile, credentials, headers, json, name, reqOpts, val;
    credentials = opts.credentials, json = opts.json, body = opts.body, headers = opts.headers, bodyFromFile = opts.bodyFromFile;
    reqOpts = {
      method: method.toUpperCase(),
      url: url,
      headers: {},
      followRedirect: false
    };
    if (credentials != null) {
      reqOpts.headers['Authorization'] = makeAuthVal(credentials);
    }
    if (headers != null) {
      for (name in headers) {
        if (!__hasProp.call(headers, name)) continue;
        val = headers[name];
        reqOpts.headers[name] = val;
      }
    }
    if (json != null) {
      reqOpts.json = json;
    }
    if (body != null) {
      reqOpts.body = body;
    }
    if (bodyFromFile != null) {
      return readFile(bodyFromFile, function(err, data) {
        if (err != null) {
          return cb(err);
        } else {
          reqOpts.body = data;
          return doRequest(reqOpts, cb);
        }
      });
    } else {
      return doRequest(reqOpts, cb);
    }
  };
  doRequest = function(opts, cb) {
    return request(opts, function(err, res, body) {
      if (err == null) {
        res.body = body;
        res.json = jsonTryParse(body);
      }
      return cb(err, res);
    });
  };
}).call(this);

==> vows-ext-0.0.7.tgz: package/lib/http-helper.js <==
(function() {
  var Request, assert, deepCopy, doRequest, exec, inspect, jsonTryParse, makeAuthVal, makeRequest, makeTopicFun, puts, readFile, replacePathVariables, request, _ref;
  var __hasProp = Object.prototype.hasOwnProperty;
  _ref = require('sys'), puts = _ref.puts, inspect = _ref.inspect;
  request = require('request');
  assert = require('assert');
  exec = require('child_process').exec;
  readFile = require('fs').readFile;
  exports.buildRequest = function(host, opts) {
    if (opts == null) {
      opts = {};
    }
    return new Request(host, opts);
  };
  jsonTryParse = function(json, val) {
    try {
      return JSON.parse(json);
    } catch (e) {
      return val || null;
    }
  };
  deepCopy = function(obj) {
    var el, name, out, val, _i, _len, _results;
    if (obj === null) {
      return null;
    } else if (Array.isArray(obj)) {
      _results = [];
      for (_i = 0, _len = obj.length; _i < _len; _i++) {
        el = obj[_i];
        _results.push(deepCopy(el));
      }
      return _results;
    } else if (typeof obj === 'object') {
      out = {};
      for (name in obj) {
        val = obj[name];
        out[name] = deepCopy(val);
      }
      return out;
    } else {
      return obj;
    }
  };
  Request = (function() {
    function Request(host, opts) {
      this.host = host;
      this.opts = deepCopy(opts);
    }
    Request.prototype.shouldRespond = function(statusCode, additionalVows) {
      var context, fun, name;
      if (additionalVows == null) {
        additionalVows = {};
      }
      context = {
        topic: makeTopicFun(this.host, this.opts)
      };
      for (name in additionalVows) {
        fun = additionalVows[name];
        context[name] = fun;
      }
      context["should respond with a " + statusCode] = function(res) {
        return assert.equal(res.statusCode, statusCode);
      };
      return context;
    };
    Request.prototype["with"] = function(moreOpts) {
      var name, newReqOpts, val;
      newReqOpts = deepCopy(this.opts);
      for (name in moreOpts) {
        val = moreOpts[name];
        newReqOpts[name] = val;
      }
      return new Request(this.host, newReqOpts);
    };
    return Request;
  })();
  makeTopicFun = function(host, opts) {
    return function(obj) {
      var method, path, reqFun, url, _ref;
      _ref = this.context.name.split(/\s+/), method = _ref[0], path = _ref[1];
      if (obj != null) {
        path = replacePathVariables(path, obj);
      }
      url = "http://" + host + path;
      return reqFun = makeRequest(method, url, opts, this.callback);
    };
  };
  makeAuthVal = function(creds) {
    var encoded;
    encoded = new Buffer("" + creds.username + ":" + creds.password).toString('base64');
    return "Basic " + encoded;
  };
  replacePathVariables = function(path, obj) {
    return path.replace(/:([a-z_]+)/gi, function(_, name) {
      var val;
      val = obj[name];
      if (typeof val === 'function') {
        return val.apply(obj);
      } else if (val != null) {
        return val;
      } else {
        return '';
      }
    });
  };
  makeRequest = function(method, url, opts, cb) {
    var body, bodyFromFile, credentials, headers, json, name, reqOpts, val;
    credentials = opts.credentials, json = opts.json, body = opts.body, headers = opts.headers, bodyFromFile = opts.bodyFromFile;
    reqOpts = {
      method: method.toUpperCase(),
      url: url,
      headers: {},
      followRedirect: false
    };
    if (credentials != null) {
      reqOpts.headers['Authorization'] = makeAuthVal(credentials);
    }
    if (headers != null) {
      for (name in headers) {
        if (!__hasProp.call(headers, name)) continue;
        val = headers[name];
        reqOpts.headers[name] = val;
      }
    }
    if (json != null) {
      reqOpts.json = json;
    }
    if (body != null) {
      reqOpts.body = body;
    }
    if (bodyFromFile != null) {
      return readFile(bodyFromFile, function(err, data) {
        if (err != null) {
          return cb(err);
        } else {
          reqOpts.body = data;
          return doRequest(reqOpts, cb);
        }
      });
    } else {
      return doRequest(reqOpts, cb);
    }
  };
  doRequest = function(opts, cb) {
    return request(opts, function(err, res, body) {
      if (err == null) {
        res.body = body;
        res.json = jsonTryParse(body);
      }
      return cb(err, res);
    });
  };
}).call(this);
